# coding: utf-8

"""
    Torizon OTA

     This API is rate limited and will return the following headers for each API call.    - X-RateLimit-Limit - The total number of requests allowed within a time period   - X-RateLimit-Remaining - The total number of requests still allowed until the end of the rate limiting period   - X-RateLimit-Reset - The number of seconds until the limit is fully reset  In addition, if an API client is rate limited, it will receive a HTTP 420 response with the following header:     - Retry-After - The number of seconds to wait until this request is allowed  

    The version of the OpenAPI document: 2.0-Beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictInt
from typing import List, Optional
from uuid import UUID
from torizon_io_api.models.create_fleet import CreateFleet
from torizon_io_api.models.fleet import Fleet
from torizon_io_api.models.pagination_result_device_info_basic import PaginationResultDeviceInfoBasic
from torizon_io_api.models.pagination_result_fleet import PaginationResultFleet
from torizon_io_api.models.update_fleet import UpdateFleet

from torizon_io_api.api_client import ApiClient, RequestSerialized
from torizon_io_api.api_response import ApiResponse
from torizon_io_api.rest import RESTResponseType


class FleetsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def delete_fleets_fleetid(
        self,
        fleet_id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete a fleet

         Permanently delete a fleet. Devices in the fleet are not deleted, but are no longer associated with the deleted fleet.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_fleets_fleetid_with_http_info(
        self,
        fleet_id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete a fleet

         Permanently delete a fleet. Devices in the fleet are not deleted, but are no longer associated with the deleted fleet.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_fleets_fleetid_without_preload_content(
        self,
        fleet_id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete a fleet

         Permanently delete a fleet. Devices in the fleet are not deleted, but are no longer associated with the deleted fleet.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_fleets_fleetid_serialize(
        self,
        fleet_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if fleet_id is not None:
            _path_params['fleetId'] = fleet_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/fleets/{fleetId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_fleets_fleetid_devices(
        self,
        fleet_id: UUID,
        request_body: Optional[List[UUID]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Remove devices from a fleet

         Removes devices, specified by a list of device UUIDs in the body, from a specific fleet.  Note: only applicable to static fleets.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param request_body:
        :type request_body: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
            '416': "RangeNotSatisfiableRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_fleets_fleetid_devices_with_http_info(
        self,
        fleet_id: UUID,
        request_body: Optional[List[UUID]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Remove devices from a fleet

         Removes devices, specified by a list of device UUIDs in the body, from a specific fleet.  Note: only applicable to static fleets.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param request_body:
        :type request_body: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
            '416': "RangeNotSatisfiableRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_fleets_fleetid_devices_without_preload_content(
        self,
        fleet_id: UUID,
        request_body: Optional[List[UUID]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Remove devices from a fleet

         Removes devices, specified by a list of device UUIDs in the body, from a specific fleet.  Note: only applicable to static fleets.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param request_body:
        :type request_body: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
            '416': "RangeNotSatisfiableRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_fleets_fleetid_devices_serialize(
        self,
        fleet_id,
        request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'request_body': '',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if fleet_id is not None:
            _path_params['fleetId'] = fleet_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request_body is not None:
            _body_params = request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/fleets/{fleetId}/devices',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_fleets(
        self,
        offset: Optional[StrictInt] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginationResultFleet:
        """Get information about all fleets in your repository

         Returns a list of fleets along with their UUIDs.         

        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_serialize(
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginationResultFleet",
            '400': "BadRequestRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_fleets_with_http_info(
        self,
        offset: Optional[StrictInt] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginationResultFleet]:
        """Get information about all fleets in your repository

         Returns a list of fleets along with their UUIDs.         

        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_serialize(
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginationResultFleet",
            '400': "BadRequestRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_fleets_without_preload_content(
        self,
        offset: Optional[StrictInt] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get information about all fleets in your repository

         Returns a list of fleets along with their UUIDs.         

        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_serialize(
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginationResultFleet",
            '400': "BadRequestRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_fleets_serialize(
        self,
        offset,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fleets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_fleets_fleetid(
        self,
        fleet_id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Fleet:
        """Get information about a single fleet in your repository

         Returns fleet info for a single fleet.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Fleet",
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_fleets_fleetid_with_http_info(
        self,
        fleet_id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Fleet]:
        """Get information about a single fleet in your repository

         Returns fleet info for a single fleet.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Fleet",
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_fleets_fleetid_without_preload_content(
        self,
        fleet_id: UUID,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get information about a single fleet in your repository

         Returns fleet info for a single fleet.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Fleet",
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_fleets_fleetid_serialize(
        self,
        fleet_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if fleet_id is not None:
            _path_params['fleetId'] = fleet_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fleets/{fleetId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_fleets_fleetid_devices(
        self,
        fleet_id: UUID,
        offset: Optional[StrictInt] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginationResultDeviceInfoBasic:
        """Get information about the devices in a single fleet

         Returns device information for all devices in the specified fleet. The schema for device data is the same as the [GET /devices](#/Devices/getDevices) endpoint.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginationResultDeviceInfoBasic",
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_fleets_fleetid_devices_with_http_info(
        self,
        fleet_id: UUID,
        offset: Optional[StrictInt] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginationResultDeviceInfoBasic]:
        """Get information about the devices in a single fleet

         Returns device information for all devices in the specified fleet. The schema for device data is the same as the [GET /devices](#/Devices/getDevices) endpoint.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginationResultDeviceInfoBasic",
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_fleets_fleetid_devices_without_preload_content(
        self,
        fleet_id: UUID,
        offset: Optional[StrictInt] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get information about the devices in a single fleet

         Returns device information for all devices in the specified fleet. The schema for device data is the same as the [GET /devices](#/Devices/getDevices) endpoint.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param offset:
        :type offset: int
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            offset=offset,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginationResultDeviceInfoBasic",
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_fleets_fleetid_devices_serialize(
        self,
        fleet_id,
        offset,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if fleet_id is not None:
            _path_params['fleetId'] = fleet_id
        # process the query parameters
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fleets/{fleetId}/devices',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_fleets(
        self,
        create_fleet: CreateFleet,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> str:
        """Create a new fleet

         Creates a new fleet. You must specify a fleet name and a fleet type, which can be `static` or `dynamic`. Static fleets are the normal way of creating fleets on the Torizon platform. Dynamic fleets have an associated pattern matching expression, and devices that match the pattern are automatically added to the group.  If you are interested in using dynamic groups, please contact support--the expression language is not fully documented yet.         

        :param create_fleet: (required)
        :type create_fleet: CreateFleet
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_fleets_serialize(
            create_fleet=create_fleet,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "str",
            '400': "BadRequestRepr",
            '409': "ConflictRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def post_fleets_with_http_info(
        self,
        create_fleet: CreateFleet,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[str]:
        """Create a new fleet

         Creates a new fleet. You must specify a fleet name and a fleet type, which can be `static` or `dynamic`. Static fleets are the normal way of creating fleets on the Torizon platform. Dynamic fleets have an associated pattern matching expression, and devices that match the pattern are automatically added to the group.  If you are interested in using dynamic groups, please contact support--the expression language is not fully documented yet.         

        :param create_fleet: (required)
        :type create_fleet: CreateFleet
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_fleets_serialize(
            create_fleet=create_fleet,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "str",
            '400': "BadRequestRepr",
            '409': "ConflictRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def post_fleets_without_preload_content(
        self,
        create_fleet: CreateFleet,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a new fleet

         Creates a new fleet. You must specify a fleet name and a fleet type, which can be `static` or `dynamic`. Static fleets are the normal way of creating fleets on the Torizon platform. Dynamic fleets have an associated pattern matching expression, and devices that match the pattern are automatically added to the group.  If you are interested in using dynamic groups, please contact support--the expression language is not fully documented yet.         

        :param create_fleet: (required)
        :type create_fleet: CreateFleet
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_fleets_serialize(
            create_fleet=create_fleet,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "str",
            '400': "BadRequestRepr",
            '409': "ConflictRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_fleets_serialize(
        self,
        create_fleet,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_fleet is not None:
            _body_params = create_fleet


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/fleets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_fleets_fleetid_devices(
        self,
        fleet_id: UUID,
        request_body: Optional[List[UUID]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Add devices to a fleet

         Adds devices, specified by a list of device UUIDs in the body, to a specific fleet.  Note: only applicable to static fleets.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param request_body:
        :type request_body: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
            '416': "RangeNotSatisfiableRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def post_fleets_fleetid_devices_with_http_info(
        self,
        fleet_id: UUID,
        request_body: Optional[List[UUID]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Add devices to a fleet

         Adds devices, specified by a list of device UUIDs in the body, to a specific fleet.  Note: only applicable to static fleets.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param request_body:
        :type request_body: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
            '416': "RangeNotSatisfiableRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def post_fleets_fleetid_devices_without_preload_content(
        self,
        fleet_id: UUID,
        request_body: Optional[List[UUID]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Add devices to a fleet

         Adds devices, specified by a list of device UUIDs in the body, to a specific fleet.  Note: only applicable to static fleets.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param request_body:
        :type request_body: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_fleets_fleetid_devices_serialize(
            fleet_id=fleet_id,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
            '404': "NotFoundRepr",
            '416': "RangeNotSatisfiableRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_fleets_fleetid_devices_serialize(
        self,
        fleet_id,
        request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'request_body': '',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if fleet_id is not None:
            _path_params['fleetId'] = fleet_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request_body is not None:
            _body_params = request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/fleets/{fleetId}/devices',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def put_fleets_fleetid(
        self,
        fleet_id: UUID,
        update_fleet: UpdateFleet,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Update fleet

         Updates fleet information.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param update_fleet: (required)
        :type update_fleet: UpdateFleet
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            update_fleet=update_fleet,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def put_fleets_fleetid_with_http_info(
        self,
        fleet_id: UUID,
        update_fleet: UpdateFleet,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Update fleet

         Updates fleet information.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param update_fleet: (required)
        :type update_fleet: UpdateFleet
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            update_fleet=update_fleet,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def put_fleets_fleetid_without_preload_content(
        self,
        fleet_id: UUID,
        update_fleet: UpdateFleet,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update fleet

         Updates fleet information.         

        :param fleet_id: (required)
        :type fleet_id: str
        :param update_fleet: (required)
        :type update_fleet: UpdateFleet
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._put_fleets_fleetid_serialize(
            fleet_id=fleet_id,
            update_fleet=update_fleet,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "BadRequestRepr",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _put_fleets_fleetid_serialize(
        self,
        fleet_id,
        update_fleet,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if fleet_id is not None:
            _path_params['fleetId'] = fleet_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if update_fleet is not None:
            _body_params = update_fleet


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/fleets/{fleetId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa
"""
    Torizon OTA

     This API is rate limited and will return the following headers for each API call.    - X-RateLimit-Limit - The total number of requests allowed within a time period   - X-RateLimit-Remaining - The total number of requests still allowed until the end of the rate limiting period   - X-RateLimit-Reset - The number of seconds until the limit is fully reset  In addition, if an API client is rate limited, it will receive a HTTP 420 response with the following header:     - Retry-After - The number of seconds to wait until this request is allowed  

    The version of the OpenAPI document: 2.0-Beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from torizon_io_api.models.bad_request_repr import BadRequestRepr
from torizon_io_api.models.client_signature import ClientSignature
from torizon_io_api.models.conflict_repr import ConflictRepr
from torizon_io_api.models.create_fleet import CreateFleet
from torizon_io_api.models.create_lockbox_request import CreateLockboxRequest
from torizon_io_api.models.create_session_request import CreateSessionRequest
from torizon_io_api.models.custom_update_data import CustomUpdateData
from torizon_io_api.models.delegation_info import DelegationInfo
from torizon_io_api.models.detailed_metric_query import DetailedMetricQuery
from torizon_io_api.models.device_create_req import DeviceCreateReq
from torizon_io_api.models.device_id import DeviceId
from torizon_io_api.models.device_info import DeviceInfo
from torizon_io_api.models.device_info_basic import DeviceInfoBasic
from torizon_io_api.models.device_info_extended import DeviceInfoExtended
from torizon_io_api.models.device_name_request import DeviceNameRequest
from torizon_io_api.models.device_notes_request import DeviceNotesRequest
from torizon_io_api.models.device_packages import DevicePackages
from torizon_io_api.models.device_session import DeviceSession
from torizon_io_api.models.device_sort import DeviceSort
from torizon_io_api.models.device_sort_direction import DeviceSortDirection
from torizon_io_api.models.device_status import DeviceStatus
from torizon_io_api.models.ecu_info_image import EcuInfoImage
from torizon_io_api.models.ecu_info_response import EcuInfoResponse
from torizon_io_api.models.edit_package import EditPackage
from torizon_io_api.models.error_representation import ErrorRepresentation
from torizon_io_api.models.external_package import ExternalPackage
from torizon_io_api.models.file_info import FileInfo
from torizon_io_api.models.fleet import Fleet
from torizon_io_api.models.fleet_metrics_outliers_request import FleetMetricsOutliersRequest
from torizon_io_api.models.fleet_metrics_outliers_response import FleetMetricsOutliersResponse
from torizon_io_api.models.fleet_type import FleetType
from torizon_io_api.models.image import Image
from torizon_io_api.models.installed_package import InstalledPackage
from torizon_io_api.models.ip_address_request import IpAddressRequest
from torizon_io_api.models.json_signed_payload import JsonSignedPayload
from torizon_io_api.models.key_data import KeyData
from torizon_io_api.models.last_ssh_session import LastSshSession
from torizon_io_api.models.metrics_response import MetricsResponse
from torizon_io_api.models.network_info import NetworkInfo
from torizon_io_api.models.not_found_repr import NotFoundRepr
from torizon_io_api.models.outlier import Outlier
from torizon_io_api.models.outlier_aggregation_method import OutlierAggregationMethod
from torizon_io_api.models.outlier_values import OutlierValues
from torizon_io_api.models.package import Package
from torizon_io_api.models.pagination_result_device_info_basic import PaginationResultDeviceInfoBasic
from torizon_io_api.models.pagination_result_device_packages import PaginationResultDevicePackages
from torizon_io_api.models.pagination_result_external_package import PaginationResultExternalPackage
from torizon_io_api.models.pagination_result_fleet import PaginationResultFleet
from torizon_io_api.models.pagination_result_network_info import PaginationResultNetworkInfo
from torizon_io_api.models.pagination_result_package import PaginationResultPackage
from torizon_io_api.models.pagination_result_string import PaginationResultString
from torizon_io_api.models.pagination_result_update_response import PaginationResultUpdateResponse
from torizon_io_api.models.post_updates400_response import PostUpdates400Response
from torizon_io_api.models.provision_info import ProvisionInfo
from torizon_io_api.models.public_keys import PublicKeys
from torizon_io_api.models.queue_response import QueueResponse
from torizon_io_api.models.range_not_satisfiable_repr import RangeNotSatisfiableRepr
from torizon_io_api.models.series import Series
from torizon_io_api.models.series_meta import SeriesMeta
from torizon_io_api.models.signature_method import SignatureMethod
from torizon_io_api.models.simple_device_info import SimpleDeviceInfo
from torizon_io_api.models.simple_device_not_affected_info import SimpleDeviceNotAffectedInfo
from torizon_io_api.models.sort_direction import SortDirection
from torizon_io_api.models.ssh_session import SshSession
from torizon_io_api.models.target_image import TargetImage
from torizon_io_api.models.target_items_sort import TargetItemsSort
from torizon_io_api.models.time_aggregation import TimeAggregation
from torizon_io_api.models.time_aggregation_method import TimeAggregationMethod
from torizon_io_api.models.update_create_result import UpdateCreateResult
from torizon_io_api.models.update_fleet import UpdateFleet
from torizon_io_api.models.update_hibernation_status_request import UpdateHibernationStatusRequest
from torizon_io_api.models.update_request import UpdateRequest
from torizon_io_api.models.update_response import UpdateResponse
from torizon_io_api.models.upstream_endpoint_error_repr import UpstreamEndpointErrorRepr
from torizon_io_api.models.user_info import UserInfo
from torizon_io_api.models.user_session import UserSession




# coding: utf-8

"""
    Torizon OTA

     This API is rate limited and will return the following headers for each API call.    - X-RateLimit-Limit - The total number of requests allowed within a time period   - X-RateLimit-Remaining - The total number of requests still allowed until the end of the rate limiting period   - X-RateLimit-Reset - The number of seconds until the limit is fully reset  In addition, if an API client is rate limited, it will receive a HTTP 420 response with the following header:     - Retry-After - The number of seconds to wait until this request is allowed  

    The version of the OpenAPI document: 2.0-Beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ExternalPackage(BaseModel):
    """
    ExternalPackage
    """ # noqa: E501
    name: StrictStr
    delegation_origin: StrictStr = Field(alias="delegationOrigin")
    version: StrictStr
    package_id: StrictStr = Field(alias="packageId")
    size: StrictInt
    hashes: Dict[str, StrictStr]
    pkg_type: Optional[StrictStr] = Field(default=None, alias="pkgType")
    hardware_ids: Optional[List[StrictStr]] = Field(default=None, alias="hardwareIds")
    created_at: Optional[datetime] = Field(default=None, alias="createdAt")
    uri: Optional[StrictStr] = None
    proprietary_meta: Optional[Any] = Field(default=None, alias="proprietaryMeta")
    __properties: ClassVar[List[str]] = ["name", "delegationOrigin", "version", "packageId", "size", "hashes", "pkgType", "hardwareIds", "createdAt", "uri", "proprietaryMeta"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExternalPackage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of proprietary_meta
        if self.proprietary_meta:
            _dict['proprietaryMeta'] = self.proprietary_meta.to_dict()
        # set to None if pkg_type (nullable) is None
        # and model_fields_set contains the field
        if self.pkg_type is None and "pkg_type" in self.model_fields_set:
            _dict['pkgType'] = None

        # set to None if created_at (nullable) is None
        # and model_fields_set contains the field
        if self.created_at is None and "created_at" in self.model_fields_set:
            _dict['createdAt'] = None

        # set to None if uri (nullable) is None
        # and model_fields_set contains the field
        if self.uri is None and "uri" in self.model_fields_set:
            _dict['uri'] = None

        # set to None if proprietary_meta (nullable) is None
        # and model_fields_set contains the field
        if self.proprietary_meta is None and "proprietary_meta" in self.model_fields_set:
            _dict['proprietaryMeta'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExternalPackage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "delegationOrigin": obj.get("delegationOrigin"),
            "version": obj.get("version"),
            "packageId": obj.get("packageId"),
            "size": obj.get("size"),
            "hashes": obj.get("hashes"),
            "pkgType": obj.get("pkgType"),
            "hardwareIds": obj.get("hardwareIds"),
            "createdAt": obj.get("createdAt"),
            "uri": obj.get("uri"),
            "proprietaryMeta": AnyOf.from_dict(obj["proprietaryMeta"]) if obj.get("proprietaryMeta") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Torizon OTA

     This API is rate limited and will return the following headers for each API call.    - X-RateLimit-Limit - The total number of requests allowed within a time period   - X-RateLimit-Remaining - The total number of requests still allowed until the end of the rate limiting period   - X-RateLimit-Reset - The number of seconds until the limit is fully reset  In addition, if an API client is rate limited, it will receive a HTTP 420 response with the following header:     - Retry-After - The number of seconds to wait until this request is allowed  

    The version of the OpenAPI document: 2.0-Beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.3"

# Define package exports
__all__ = [
    "DeviceMetricsApi",
    "DevicesApi",
    "FleetsApi",
    "PackagesApi",
    "RemoteAccessApi",
    "UpdatesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BadRequestRepr",
    "ClientSignature",
    "ConflictRepr",
    "CreateFleet",
    "CreateLockboxRequest",
    "CreateSessionRequest",
    "CustomUpdateData",
    "DelegationInfo",
    "DetailedMetricQuery",
    "DeviceCreateReq",
    "DeviceId",
    "DeviceInfo",
    "DeviceInfoBasic",
    "DeviceInfoExtended",
    "DeviceNameRequest",
    "DeviceNotesRequest",
    "DevicePackages",
    "DeviceSession",
    "DeviceSort",
    "DeviceSortDirection",
    "DeviceStatus",
    "EcuInfoImage",
    "EcuInfoResponse",
    "EditPackage",
    "ErrorRepresentation",
    "ExternalPackage",
    "FileInfo",
    "Fleet",
    "FleetMetricsOutliersRequest",
    "FleetMetricsOutliersResponse",
    "FleetType",
    "Image",
    "InstalledPackage",
    "IpAddressRequest",
    "JsonSignedPayload",
    "KeyData",
    "LastSshSession",
    "MetricsResponse",
    "NetworkInfo",
    "NotFoundRepr",
    "Outlier",
    "OutlierAggregationMethod",
    "OutlierValues",
    "Package",
    "PaginationResultDeviceInfoBasic",
    "PaginationResultDevicePackages",
    "PaginationResultExternalPackage",
    "PaginationResultFleet",
    "PaginationResultNetworkInfo",
    "PaginationResultPackage",
    "PaginationResultString",
    "PaginationResultUpdateResponse",
    "PostUpdates400Response",
    "ProvisionInfo",
    "PublicKeys",
    "QueueResponse",
    "RangeNotSatisfiableRepr",
    "Series",
    "SeriesMeta",
    "SignatureMethod",
    "SimpleDeviceInfo",
    "SimpleDeviceNotAffectedInfo",
    "SortDirection",
    "SshSession",
    "TargetImage",
    "TargetItemsSort",
    "TimeAggregation",
    "TimeAggregationMethod",
    "UpdateCreateResult",
    "UpdateFleet",
    "UpdateHibernationStatusRequest",
    "UpdateRequest",
    "UpdateResponse",
    "UpstreamEndpointErrorRepr",
    "UserInfo",
    "UserSession",
]

# import apis into sdk package
from torizon_io_api.api.device_metrics_api import DeviceMetricsApi as DeviceMetricsApi
from torizon_io_api.api.devices_api import DevicesApi as DevicesApi
from torizon_io_api.api.fleets_api import FleetsApi as FleetsApi
from torizon_io_api.api.packages_api import PackagesApi as PackagesApi
from torizon_io_api.api.remote_access_api import RemoteAccessApi as RemoteAccessApi
from torizon_io_api.api.updates_api import UpdatesApi as UpdatesApi

# import ApiClient
from torizon_io_api.api_response import ApiResponse as ApiResponse
from torizon_io_api.api_client import ApiClient as ApiClient
from torizon_io_api.configuration import Configuration as Configuration
from torizon_io_api.exceptions import OpenApiException as OpenApiException
from torizon_io_api.exceptions import ApiTypeError as ApiTypeError
from torizon_io_api.exceptions import ApiValueError as ApiValueError
from torizon_io_api.exceptions import ApiKeyError as ApiKeyError
from torizon_io_api.exceptions import ApiAttributeError as ApiAttributeError
from torizon_io_api.exceptions import ApiException as ApiException

# import models into sdk package
from torizon_io_api.models.bad_request_repr import BadRequestRepr as BadRequestRepr
from torizon_io_api.models.client_signature import ClientSignature as ClientSignature
from torizon_io_api.models.conflict_repr import ConflictRepr as ConflictRepr
from torizon_io_api.models.create_fleet import CreateFleet as CreateFleet
from torizon_io_api.models.create_lockbox_request import CreateLockboxRequest as CreateLockboxRequest
from torizon_io_api.models.create_session_request import CreateSessionRequest as CreateSessionRequest
from torizon_io_api.models.custom_update_data import CustomUpdateData as CustomUpdateData
from torizon_io_api.models.delegation_info import DelegationInfo as DelegationInfo
from torizon_io_api.models.detailed_metric_query import DetailedMetricQuery as DetailedMetricQuery
from torizon_io_api.models.device_create_req import DeviceCreateReq as DeviceCreateReq
from torizon_io_api.models.device_id import DeviceId as DeviceId
from torizon_io_api.models.device_info import DeviceInfo as DeviceInfo
from torizon_io_api.models.device_info_basic import DeviceInfoBasic as DeviceInfoBasic
from torizon_io_api.models.device_info_extended import DeviceInfoExtended as DeviceInfoExtended
from torizon_io_api.models.device_name_request import DeviceNameRequest as DeviceNameRequest
from torizon_io_api.models.device_notes_request import DeviceNotesRequest as DeviceNotesRequest
from torizon_io_api.models.device_packages import DevicePackages as DevicePackages
from torizon_io_api.models.device_session import DeviceSession as DeviceSession
from torizon_io_api.models.device_sort import DeviceSort as DeviceSort
from torizon_io_api.models.device_sort_direction import DeviceSortDirection as DeviceSortDirection
from torizon_io_api.models.device_status import DeviceStatus as DeviceStatus
from torizon_io_api.models.ecu_info_image import EcuInfoImage as EcuInfoImage
from torizon_io_api.models.ecu_info_response import EcuInfoResponse as EcuInfoResponse
from torizon_io_api.models.edit_package import EditPackage as EditPackage
from torizon_io_api.models.error_representation import ErrorRepresentation as ErrorRepresentation
from torizon_io_api.models.external_package import ExternalPackage as ExternalPackage
from torizon_io_api.models.file_info import FileInfo as FileInfo
from torizon_io_api.models.fleet import Fleet as Fleet
from torizon_io_api.models.fleet_metrics_outliers_request import FleetMetricsOutliersRequest as FleetMetricsOutliersRequest
from torizon_io_api.models.fleet_metrics_outliers_response import FleetMetricsOutliersResponse as FleetMetricsOutliersResponse
from torizon_io_api.models.fleet_type import FleetType as FleetType
from torizon_io_api.models.image import Image as Image
from torizon_io_api.models.installed_package import InstalledPackage as InstalledPackage
from torizon_io_api.models.ip_address_request import IpAddressRequest as IpAddressRequest
from torizon_io_api.models.json_signed_payload import JsonSignedPayload as JsonSignedPayload
from torizon_io_api.models.key_data import KeyData as KeyData
from torizon_io_api.models.last_ssh_session import LastSshSession as LastSshSession
from torizon_io_api.models.metrics_response import MetricsResponse as MetricsResponse
from torizon_io_api.models.network_info import NetworkInfo as NetworkInfo
from torizon_io_api.models.not_found_repr import NotFoundRepr as NotFoundRepr
from torizon_io_api.models.outlier import Outlier as Outlier
from torizon_io_api.models.outlier_aggregation_method import OutlierAggregationMethod as OutlierAggregationMethod
from torizon_io_api.models.outlier_values import OutlierValues as OutlierValues
from torizon_io_api.models.package import Package as Package
from torizon_io_api.models.pagination_result_device_info_basic import PaginationResultDeviceInfoBasic as PaginationResultDeviceInfoBasic
from torizon_io_api.models.pagination_result_device_packages import PaginationResultDevicePackages as PaginationResultDevicePackages
from torizon_io_api.models.pagination_result_external_package import PaginationResultExternalPackage as PaginationResultExternalPackage
from torizon_io_api.models.pagination_result_fleet import PaginationResultFleet as PaginationResultFleet
from torizon_io_api.models.pagination_result_network_info import PaginationResultNetworkInfo as PaginationResultNetworkInfo
from torizon_io_api.models.pagination_result_package import PaginationResultPackage as PaginationResultPackage
from torizon_io_api.models.pagination_result_string import PaginationResultString as PaginationResultString
from torizon_io_api.models.pagination_result_update_response import PaginationResultUpdateResponse as PaginationResultUpdateResponse
from torizon_io_api.models.post_updates400_response import PostUpdates400Response as PostUpdates400Response
from torizon_io_api.models.provision_info import ProvisionInfo as ProvisionInfo
from torizon_io_api.models.public_keys import PublicKeys as PublicKeys
from torizon_io_api.models.queue_response import QueueResponse as QueueResponse
from torizon_io_api.models.range_not_satisfiable_repr import RangeNotSatisfiableRepr as RangeNotSatisfiableRepr
from torizon_io_api.models.series import Series as Series
from torizon_io_api.models.series_meta import SeriesMeta as SeriesMeta
from torizon_io_api.models.signature_method import SignatureMethod as SignatureMethod
from torizon_io_api.models.simple_device_info import SimpleDeviceInfo as SimpleDeviceInfo
from torizon_io_api.models.simple_device_not_affected_info import SimpleDeviceNotAffectedInfo as SimpleDeviceNotAffectedInfo
from torizon_io_api.models.sort_direction import SortDirection as SortDirection
from torizon_io_api.models.ssh_session import SshSession as SshSession
from torizon_io_api.models.target_image import TargetImage as TargetImage
from torizon_io_api.models.target_items_sort import TargetItemsSort as TargetItemsSort
from torizon_io_api.models.time_aggregation import TimeAggregation as TimeAggregation
from torizon_io_api.models.time_aggregation_method import TimeAggregationMethod as TimeAggregationMethod
from torizon_io_api.models.update_create_result import UpdateCreateResult as UpdateCreateResult
from torizon_io_api.models.update_fleet import UpdateFleet as UpdateFleet
from torizon_io_api.models.update_hibernation_status_request import UpdateHibernationStatusRequest as UpdateHibernationStatusRequest
from torizon_io_api.models.update_request import UpdateRequest as UpdateRequest
from torizon_io_api.models.update_response import UpdateResponse as UpdateResponse
from torizon_io_api.models.upstream_endpoint_error_repr import UpstreamEndpointErrorRepr as UpstreamEndpointErrorRepr
from torizon_io_api.models.user_info import UserInfo as UserInfo
from torizon_io_api.models.user_session import UserSession as UserSession




# coding: utf-8

"""
    Torizon OTA

     This API is rate limited and will return the following headers for each API call.    - X-RateLimit-Limit - The total number of requests allowed within a time period   - X-RateLimit-Remaining - The total number of requests still allowed until the end of the rate limiting period   - X-RateLimit-Reset - The number of seconds until the limit is fully reset  In addition, if an API client is rate limited, it will receive a HTTP 420 response with the following header:     - Retry-After - The number of seconds to wait until this request is allowed  

    The version of the OpenAPI document: 2.0-Beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TimeAggregationMethod(str, Enum):
    """
    TimeAggregationMethod
    """

    """
    allowed enum values
    """
    LAST = 'last'
    AVERAGE = 'average'
    MAX = 'max'
    MIN = 'min'
    COUNT = 'count'
    NONE = 'none'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TimeAggregationMethod from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Torizon OTA

     This API is rate limited and will return the following headers for each API call.    - X-RateLimit-Limit - The total number of requests allowed within a time period   - X-RateLimit-Remaining - The total number of requests still allowed until the end of the rate limiting period   - X-RateLimit-Reset - The number of seconds until the limit is fully reset  In addition, if an API client is rate limited, it will receive a HTTP 420 response with the following header:     - Retry-After - The number of seconds to wait until this request is allowed  

    The version of the OpenAPI document: 2.0-Beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from torizon_io_api.models.device_status import DeviceStatus
from typing import Optional, Set
from typing_extensions import Self

class DeviceInfoBasic(BaseModel):
    """
    DeviceInfoBasic
    """ # noqa: E501
    device_uuid: UUID = Field(alias="deviceUuid")
    device_name: StrictStr = Field(alias="deviceName")
    device_id: StrictStr = Field(alias="deviceId")
    last_seen: Optional[datetime] = Field(default=None, alias="lastSeen")
    created_at: datetime = Field(alias="createdAt")
    activated_at: Optional[datetime] = Field(default=None, alias="activatedAt")
    device_status: DeviceStatus = Field(alias="deviceStatus")
    notes: StrictStr
    attributes: Optional[Dict[str, StrictStr]] = None
    hibernated: StrictBool
    __properties: ClassVar[List[str]] = ["deviceUuid", "deviceName", "deviceId", "lastSeen", "createdAt", "activatedAt", "deviceStatus", "notes", "attributes", "hibernated"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DeviceInfoBasic from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if last_seen (nullable) is None
        # and model_fields_set contains the field
        if self.last_seen is None and "last_seen" in self.model_fields_set:
            _dict['lastSeen'] = None

        # set to None if activated_at (nullable) is None
        # and model_fields_set contains the field
        if self.activated_at is None and "activated_at" in self.model_fields_set:
            _dict['activatedAt'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DeviceInfoBasic from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "deviceUuid": obj.get("deviceUuid"),
            "deviceName": obj.get("deviceName"),
            "deviceId": obj.get("deviceId"),
            "lastSeen": obj.get("lastSeen"),
            "createdAt": obj.get("createdAt"),
            "activatedAt": obj.get("activatedAt"),
            "deviceStatus": obj.get("deviceStatus"),
            "notes": obj.get("notes"),
            "attributes": obj.get("attributes"),
            "hibernated": obj.get("hibernated")
        })
        return _obj





# flake8: noqa

# import apis into api package
from torizon_io_api.api.device_metrics_api import DeviceMetricsApi
from torizon_io_api.api.devices_api import DevicesApi
from torizon_io_api.api.fleets_api import FleetsApi
from torizon_io_api.api.packages_api import PackagesApi
from torizon_io_api.api.remote_access_api import RemoteAccessApi
from torizon_io_api.api.updates_api import UpdatesApi

